Imports System.Collections.Generic

Public Enum PageOrientation
    ' Fields
    Landscape = 2
    Portrait = 1
End Enum

Public Class DocumentProperies
    ' Fields
    Private m_sDocumentName As String
    Private m_sDeviceName As String
    Private m_iPrintJobId As Integer
    Private m_sMachineName As String
    Private m_sUserName As String
    Private m_iSessionId As Integer
    Private m_iHorizontalResolution As Integer
    Private m_iVerticalResolution As Integer
    Private m_PageOrientation As PageOrientation
    Private m_iPaperSize As Integer
    Private m_sPaperSizeName As String
    Private m_iPaperWidth As Integer
    Private m_iPaperLength As Integer
    Private m_iPagesQuantity As Integer
    Private m_iCopiesQuantity As Integer
    Private m_iPaperBin As Integer
    Private m_sPaperBinName As String
    Private m_bCollate As Boolean
    Private m_Files As List(Of String) = New List(Of String)

    ' Properties
    Public Property Name() As String
        Get
            Return m_sDocumentName
        End Get
        Set(ByVal value As String)
            m_sDocumentName = value
        End Set
    End Property

    Public Property MachineName() As String
        Get
            Return m_sMachineName
        End Get
        Set(ByVal value As String)
            m_sMachineName = value
        End Set
    End Property

    Public Property UserName() As String
        Get
            Return m_sUserName
        End Get
        Set(ByVal value As String)
            m_sUserName = value
        End Set
    End Property

    Public Property SessionID() As Integer
        Get
            Return m_iSessionId
        End Get
        Set(ByVal value As Integer)
            m_iSessionId = value
        End Set
    End Property

    Public Property JobID() As Integer
        Get
            Return m_iPrintJobId
        End Get
        Set(ByVal value As Integer)
            m_iPrintJobId = value
        End Set
    End Property

    Public Property HorizontalResolution() As Integer
        Get
            Return m_iHorizontalResolution
        End Get
        Set(ByVal value As Integer)
            m_iHorizontalResolution = value
        End Set
    End Property

    Public Property VerticalResolution() As Integer
        Get
            Return m_iVerticalResolution
        End Get
        Set(ByVal value As Integer)
            m_iVerticalResolution = value
        End Set
    End Property

    Public Property Orientation() As PageOrientation
        Get
            Return m_PageOrientation
        End Get
        Set(ByVal value As PageOrientation)
            m_PageOrientation = value
        End Set
    End Property

    Public Property PaperSize() As Integer
        Get
            Return m_iPaperSize
        End Get
        Set(ByVal value As Integer)
            m_iPaperSize = value
        End Set
    End Property

    Public Property PaperSizeName() As String
        Get
            Return m_sPaperSizeName
        End Get
        Set(ByVal value As String)
            m_sPaperSizeName = value
        End Set
    End Property

    Public Property PaperWidth() As Integer
        Get
            Return m_iPaperWidth
        End Get
        Set(ByVal value As Integer)
            m_iPaperWidth = value
        End Set
    End Property

    Public Property PaperLength() As Integer
        Get
            Return m_iPaperLength
        End Get
        Set(ByVal value As Integer)
            m_iPaperLength = value
        End Set
    End Property

    Public Property Pages() As Integer
        Get
            Return m_iPagesQuantity
        End Get
        Set(ByVal value As Integer)
            m_iPagesQuantity = value
        End Set
    End Property

    Public Property Copies() As Integer
        Get
            Return m_iCopiesQuantity
        End Get
        Set(ByVal value As Integer)
            m_iCopiesQuantity = value
        End Set
    End Property

    Public Property Bin() As Integer
        Get
            Return m_iPaperBin
        End Get
        Set(ByVal value As Integer)
            m_iPaperBin = value
        End Set
    End Property
        
    Public Property BinName() As String
        Get
            Return m_sPaperBinName
        End Get
        Set(ByVal value As String)
            m_sPaperBinName = value
        End Set
    End Property

    Public Property Collate() As Boolean
        Get
            Return m_bCollate
        End Get
        Set(ByVal value As Boolean)
            m_bCollate = value
        End Set
    End Property
        
    Public Property Files() As List(Of String)
        Get
            Return m_Files
        End Get
        Set(ByVal value As List(Of String))
            m_Files = value
        End Set
    End Property

    ' Constructor, simply zeroes class members
    Public Sub New()
        ClearAll(False)
    End Sub

    'This function parses the specified .ini file and fills class members
    Public Function Retrieve(ByVal sIniFileName As String) As Boolean

        ClearAll(True)

        Dim Ini As IniFile = New IniFile(String.Empty)
        If (Ini.SetFileName(sIniFileName) = False) Then
            Return False
        End If

        m_sDeviceName = Ini.IniReadValue("Device", "DeviceName", "Unknown")
        m_sDocumentName = Ini.IniReadValue("Document", "Name", "")
        m_iPrintJobId = Integer.Parse(Ini.IniReadValue("Document", "JobID", "0"))
        m_sMachineName = Ini.IniReadValue("Document", "MachineName", "")
        m_sUserName = Ini.IniReadValue("Document", "UserName", "")
        m_iSessionId = Integer.Parse(Ini.IniReadValue("Document", "SessionID", "0"))
        m_iHorizontalResolution = Integer.Parse(Ini.IniReadValue("Document", "HorizontalResolution", "0"))
        m_iVerticalResolution = Integer.Parse(Ini.IniReadValue("Document", "VerticalResolution", "0"))
        m_PageOrientation = Integer.Parse(Ini.IniReadValue("Document", "Orientation", "1"))
        m_iPaperSize = Integer.Parse(Ini.IniReadValue("Document", "PaperSize", "0"))
        m_sPaperSizeName = Ini.IniReadValue("Document", "PaperSizeName", "Unknown")
        m_iPaperWidth = Integer.Parse(Ini.IniReadValue("Document", "PaperWidth", "0"))
        m_iPaperLength = Integer.Parse(Ini.IniReadValue("Document", "PaperLength", "0"))
        m_iPagesQuantity = Integer.Parse(Ini.IniReadValue("Document", "Pages", "0"))
        m_iCopiesQuantity = Integer.Parse(Ini.IniReadValue("Document", "Copies", "0"))
        m_bCollate = (Integer.Parse(Ini.IniReadValue("Document", "Collate", "0")) <> 0)
        m_iPaperBin = Integer.Parse(Ini.IniReadValue("Document", "Bin", "0"))
        m_sPaperBinName = Ini.IniReadValue("Document", "BinName", "Unknown")

        Dim s As String
        Dim i As Integer
        For i = 0 To m_iPagesQuantity - 1
            s = String.Format("File{0}", i)
            m_Files.Add(Ini.IniReadValue("EMF", s, ""))
        Next i

        Return True
    End Function

    'This function sets all parameters to zero or empty string
    Public Sub ClearAll(ByVal doClearStrings As Boolean)

        If (doClearStrings = True) Then
            m_sDeviceName = String.Empty
            m_sDocumentName = String.Empty
            m_sMachineName = String.Empty
            m_sUserName = String.Empty
            m_sPaperSizeName = String.Empty
            m_sPaperBinName = String.Empty
            m_Files.Clear()
        End If

        m_iPrintJobId = m_iSessionId = 0
        m_iHorizontalResolution = m_iVerticalResolution = 0
        m_iPaperSize = m_iPaperWidth = m_iPaperLength = 0
        m_iPagesQuantity = m_iCopiesQuantity = 0
        m_iPaperBin = 0

        m_PageOrientation = PageOrientation.Portrait
        m_bCollate = False

    End Sub
End Class
