Imports System
Imports System.Drawing
Imports System.Drawing.Imaging

Public Class PrintPreviwer

    Private m_currentPage As Integer = -1
    Private m_commandLine As String = String.Empty
    Private m_docProps As PrintPreviewer.DocumentProperies = New PrintPreviewer.DocumentProperies()

    ' Constructor 
    Public Sub New(ByVal commandLine As String)
        InitializeComponent()

        m_pictureBox.Image = Nothing
        m_commandLine = commandLine
    End Sub

    ' Load form
    Private Sub PrintPreviwer_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        'Parse .ini file
        If (m_docProps.Retrieve(m_commandLine) = False) Then
            m_listBox.Items.Add("Invalid command line parameter!")
        Else
            'Fill in the ListBox
            fillListBox()

            'Load 1st page preview
            If (m_docProps.Files.Count > 0) Then
                loadPreview(0)
            End If
        End If
    End Sub

    ' Click on button
    Private Sub m_buttonClose_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles m_buttonClose.Click
        Close()
    End Sub

    ' Double click on picture box
    Private Sub m_pictureBox_DoubleClick(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles m_pictureBox.DoubleClick
        Try
            ' Open page preview with the default application
            System.Diagnostics.Process.Start(m_docProps.Files(m_currentPage))
        Catch
        End Try
    End Sub

    ' Select string in listbox
    Private Sub m_listBox_SelectedIndexChanged(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles m_listBox.SelectedIndexChanged
        Try
            ' If the clicked item of the listbox corresponds to a printed page
            ' then appropriate .emf file will be opened on the preview panel
            loadPreview(m_listBox.SelectedIndex - m_listBox.Tag)
        Catch
        End Try
    End Sub

    ' Ovveride pain function for picture box
    Private Sub m_pictureBox_Paint(ByVal sender As System.Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles m_pictureBox.Paint
        ' Draw string "No image" on preview panel if there are not images
        If (m_commandLine = String.Empty) Then
            ' Create font and brush.
            Dim font As Font = New Font("Arial", 12, FontStyle.Bold)
            Dim brush As SolidBrush = New SolidBrush(Color.Black)

            ' Set format of string.
            Dim stringFormat As StringFormat = New StringFormat()
            stringFormat.LineAlignment = StringAlignment.Center
            stringFormat.Alignment = StringAlignment.Center

            Dim rect As Rectangle = m_pictureBox.ClientRectangle

            e.Graphics.DrawString("No image", font, brush, rect, stringFormat)
        End If
    End Sub

    'This functions fills in the ListBox (print job details)
    Private Sub fillListBox()
        m_listBox.BeginUpdate()
        m_listBox.Items.Add("Document name: " + m_docProps.Name)
        Dim str As String = String.Format("Print job ID: {0}", m_docProps.JobID)
        m_listBox.Items.Add(Str)
        m_listBox.Items.Add("")

        str = String.Format("Horizontal resolution: {0} dpi", m_docProps.HorizontalResolution)
        m_listBox.Items.Add(str)
        str = String.Format("Vertical resolution: {0} dpi", m_docProps.VerticalResolution)
        m_listBox.Items.Add(str)
        m_listBox.Items.Add("")

        str = String.Format("Paper size: {0} ({1} x {2} mm)", m_docProps.PaperSizeName, m_docProps.PaperWidth / 10, m_docProps.PaperLength / 10)
        m_listBox.Items.Add(str)
        m_listBox.Items.Add("Paper bin: " + m_docProps.BinName)
        If m_docProps.Orientation = PageOrientation.Portrait Then
            m_listBox.Items.Add("Orientation: Portrait")
        Else
            m_listBox.Items.Add("Orientation: Landscape")
        End If
        m_listBox.Items.Add("")

        str = String.Format("Pages: {0}", m_docProps.Pages)
        m_listBox.Items.Add(str)
        str = String.Format("Copies: {0}", m_docProps.Copies)
        m_listBox.Items.Add(str)
        If m_docProps.Collate = True Then
            m_listBox.Items.Add("Collate: Yes")
        Else
            m_listBox.Items.Add("Collate: No")
        End If
        m_listBox.Items.Add("")

        If (m_docProps.Files.Count = 0) Then
            m_listBox.Items.Add("There are no printed pages")
        Else

            m_listBox.Items.Add("Printed pages (click to preview):")
            Dim i
            For i = 0 To m_docProps.Files.Count - 1
                ' Add file name to the list
                Dim file As System.IO.FileInfo = New System.IO.FileInfo(m_docProps.Files(i))
                str = String.Format("    Page {0}: {1}", i + 1, file.Name)
                Dim x As Integer = m_listBox.Items.Add(str)

                ' Select 1st page in the list
                If (i = 0) Then
                    m_listBox.SelectedIndex = x
                    m_listBox.Tag = x
                End If
            Next i
        End If
        m_listBox.EndUpdate()
    End Sub

    ' This function loads the specified page to the preview panel
    Private Sub loadPreview(ByVal pageIndex As Integer)
        Dim metafile As Metafile = Nothing

        If (pageIndex >= 0) Then
            metafile = New Metafile(m_docProps.Files(pageIndex))
        End If
        If metafile.Equals(Nothing) Then
            m_currentPage = -1
        Else
            m_pictureBox.Image = metafile
            m_currentPage = pageIndex

            ' Update preview's label
            m_previewLabel.Text = String.Format("Page preview (page {0}):", pageIndex + 1)
        End If
    End Sub

End Class

Friend Class Program
    ' Methods
    <STAThread()> _
    Public Shared Sub Main(ByVal args As String())
        Application.EnableVisualStyles()
        Application.SetCompatibleTextRenderingDefault(False)

        Dim commandLine As String = String.Empty

        If (args.Length > 0) Then
            commandLine = args(0)
        End If
        Application.Run(New PrintPreviwer(commandLine))
    End Sub

End Class